( cd usr/man/man2 ; rm -rf lsetxattr.2.gz )
( cd usr/man/man2 ; ln -sf setxattr.2.gz lsetxattr.2.gz )
( cd usr/man/man2 ; rm -rf flistxattr.2.gz )
( cd usr/man/man2 ; ln -sf listxattr.2.gz flistxattr.2.gz )
( cd usr/man/man2 ; rm -rf fremovexattr.2.gz )
( cd usr/man/man2 ; ln -sf removexattr.2.gz fremovexattr.2.gz )
( cd usr/man/man2 ; rm -rf lgetxattr.2.gz )
( cd usr/man/man2 ; ln -sf getxattr.2.gz lgetxattr.2.gz )
( cd usr/man/man2 ; rm -rf fsetxattr.2.gz )
( cd usr/man/man2 ; ln -sf setxattr.2.gz fsetxattr.2.gz )
( cd usr/man/man2 ; rm -rf fgetxattr.2.gz )
( cd usr/man/man2 ; ln -sf getxattr.2.gz fgetxattr.2.gz )
( cd usr/man/man2 ; rm -rf lremovexattr.2.gz )
( cd usr/man/man2 ; ln -sf removexattr.2.gz lremovexattr.2.gz )
( cd usr/man/man2 ; rm -rf llistxattr.2.gz )
( cd usr/man/man2 ; ln -sf listxattr.2.gz llistxattr.2.gz )
( cd usr/man/man3 ; rm -rf attr_multif.3.gz )
( cd usr/man/man3 ; ln -sf attr_multi.3.gz attr_multif.3.gz )
( cd usr/man/man3 ; rm -rf attr_getf.3.gz )
( cd usr/man/man3 ; ln -sf attr_get.3.gz attr_getf.3.gz )
( cd usr/man/man3 ; rm -rf attr_removef.3.gz )
( cd usr/man/man3 ; ln -sf attr_remove.3.gz attr_removef.3.gz )
( cd usr/man/man3 ; rm -rf attr_listf.3.gz )
( cd usr/man/man3 ; ln -sf attr_list.3.gz attr_listf.3.gz )
( cd usr/man/man3 ; rm -rf attr_setf.3.gz )
( cd usr/man/man3 ; ln -sf attr_set.3.gz attr_setf.3.gz )
( cd usr/lib ; rm -rf libattr.so )
( cd usr/lib ; ln -sf /lib/libattr.so.1 libattr.so )
( cd lib ; rm -rf libattr.so.1 )
( cd lib ; ln -sf libattr.so.1.1.0 libattr.so.1 )
